@@ -36,11 +36,12 @@ import six
 try:
     from collections.abc import Mapping, Sequence
 except ImportError:  # py2
+    # pylint: disable=deprecated-class
     from collections import Mapping, Sequence
 
 from pywbem import CIMInstance, CIMInstanceName, CIMClass, CIMClassName, \
     CIMParameter, CIMError, CIM_ERR_NOT_FOUND, CIM_ERR_INVALID_PARAMETER, \
-    CIM_ERR_INVALID_CLASS, CIM_ERR_METHOD_NOT_FOUND, cimtype
+    CIM_ERR_INVALID_CLASS, CIM_ERR_METHOD_NOT_FOUND, cimtype, CIM_ERR_FAILED
 
 from pywbem._utils import _format
 from pywbem._nocasedict import NocaseDict
@@ -213,6 +214,13 @@ class ProviderDispatcher(BaseProvider):
                         "exist in namespace {1!A} of the CIM repository.",
                         NewInstance.classname, namespace))
 
+        if "Abstract" in creation_class.qualifiers:
+            raise CIMError(
+                CIM_ERR_FAILED,
+                _format("CreateInstance failed. Cannot instantiate abstract "
+                        "class {0!A} in Namespace {1!A}.",
+                        NewInstance.classname, namespace))
+
         # Verify that the properties in the new instance are exposed by the
         # creation class and have the correct type-related attributes.
         for pn in NewInstance.properties:
