@@ -31,10 +31,10 @@ import os
 import time
 import re
 from xml.dom import minidom
-try:
-    from unittest.mock import Mock
-except ImportError:
-    from mock import Mock
+# try:
+#    from unittest.mock import Mock
+# except ImportError:
+#    from mock import Mock
 import six
 
 
@@ -59,6 +59,9 @@ from ._utils import _uprint
 
 from ._namespaceprovider import CIMNamespaceProvider
 
+from ._subscriptionproviders import CIMIndicationSubscriptionProvider, \
+    CIMListenerDestinationProvider, CIMIndicationFilterProvider
+
 __all__ = ['FakedWBEMConnection']
 
 # Fake Server default values for parameters that apply to repo and operations
@@ -144,7 +147,7 @@ class FakedWBEMConnection(WBEMConnection):
     def __init__(self, default_namespace=DEFAULT_NAMESPACE,
                  use_pull_operations=False, stats_enabled=False,
                  timeout=None, response_delay=None,
-                 disable_pull_operations=None):
+                 disable_pull_operations=None, url=None):
         """
         Parameters:
 
@@ -187,6 +190,12 @@ class FakedWBEMConnection(WBEMConnection):
             The :attr:`~pywbem_mock.FakedWBEMConnection.disable_pull_operations`
             property can be used to set this variable.
 
+        url (:term:`string`):
+            Defines a url to replace the default http://FakedURL.5988 url which
+            is passed to the superclass. The url must be an acceptable syntax
+            for WBEMConnection initialization.  This is useful when multiple
+            mocks are required for testing.
+
         Raises:
           ValueError for invalid arguments
         """
@@ -201,7 +210,7 @@ class FakedWBEMConnection(WBEMConnection):
         self._disable_pull_operations = disable_pull_operations
 
         super(FakedWBEMConnection, self).__init__(
-            'http://FakedUrl:5988',
+            url or 'http://FakedUrl:5988',
             default_namespace=default_namespace,
             use_pull_operations=use_pull_operations,
             stats_enabled=stats_enabled, timeout=timeout)
@@ -240,8 +249,8 @@ class FakedWBEMConnection(WBEMConnection):
         # instance of this class as the client interface.
         self._mofwbemconnection = _MockMOFWBEMConnection(self)
 
-        self._imethodcall = Mock(side_effect=self._mock_imethodcall)
-        self._methodcall = Mock(side_effect=self._mock_methodcall)
+        self._imethodcall = self._mock_imethodcall
+        self._methodcall = self._mock_methodcall
 
     @property
     def namespaces(self):
@@ -355,6 +364,44 @@ class FakedWBEMConnection(WBEMConnection):
             "super={super})",
             s=self, super=super(FakedWBEMConnection, self).__repr__())
 
+    def copy(self):
+        """
+        *New in pywbem 1.3.*
+
+        Return a deep copy of the object with internal state reset and reusing
+        the same repository and registries.
+
+        The returned object uses the same repository, provider registry and
+        provider dependent registry objects as the original object.
+        Besides that, all other user-specifiable attributes of the object are
+        deep-copied, and all other internal state is reset.
+        """
+        cpy = FakedWBEMConnection(
+            default_namespace=self.default_namespace,
+            use_pull_operations=self.use_pull_operations,
+            stats_enabled=self.stats_enabled,
+            timeout=self.timeout,
+            response_delay=self._response_delay,
+            disable_pull_operations=self._disable_pull_operations,
+            url=self.url,
+        )  # only immutable parameters
+
+        # pylint: disable=protected-access
+
+        # Reuse repository and registries of the original object
+        cpy._cimrepository = self._cimrepository
+        cpy._provider_registry = self._provider_registry
+        cpy._provider_dependent_registry = self._provider_dependent_registry
+
+        # These objects know about the repository and registries, but other
+        # wise do not have internal state
+        cpy._providerdispatcher = self._providerdispatcher
+        cpy._mainprovider = self._mainprovider
+
+        # pylint: enable=protected-access
+
+        return cpy
+
     # The namespace management methods must be in the this class directly
     # so they can be access with call to the methods from instance of
     # this class. they are considered part of the external API.
@@ -491,6 +538,69 @@ class FakedWBEMConnection(WBEMConnection):
                                schema_pragma_files=schema_pragma_file,
                                verbose=verbose)
 
+    def install_subscription_providers(self, interop_namespace,
+                                       schema_pragma_file=None,
+                                       verbose=None):
+        """
+        FakedWBEMConnection user method to install the indication subscription
+        providers in the Interop namespace where the proposed interop_namespace
+        is defined by the parameter interop_namespace
+
+        **Experimental:** *New in pywbem 1.3.0 as experimental.*
+
+        Because these provider requires a set of classes from the
+        DMTF schema, the schema_pragma_file install the schema is required.
+
+        This method should only be called once at the creation of the
+        mock environment.
+
+        Parameters:
+
+          interop_namespace  (:term:`string`):
+            The Interop namespace defined for this environment
+
+          schema_pragma_file (:term:`string`):
+            File path defining a CIM schema pragma file for the set of
+            CIM classes that make up a schema such as the DMTF schema.
+            This file must contain a pragma statement for each of the
+            classes defined in the schema.
+
+            If None, no attempt is made to any CIM classes required for the
+            provider and it is assumed that the CIM classes are already
+            installed
+
+          verbose (:class:`py:bool`):
+            If True, displays progress information as providers are installed.
+
+        Raises:
+          :exc:`~pywbem.CIMError`: with status code appropriate for any
+          error encountered in the installation of the provider.
+        """
+
+        # Determine if an interop namespace already exists and confirm that
+        # we are using a valid interop namespace name to add the
+        # new namespace.
+        if not self.find_interop_namespace():
+            self.add_namespace(interop_namespace)
+
+        provider = CIMListenerDestinationProvider(self.cimrepository)
+        self.register_provider(provider,
+                               namespaces=interop_namespace,
+                               schema_pragma_files=schema_pragma_file,
+                               verbose=verbose)
+
+        provider = CIMIndicationFilterProvider(self.cimrepository)
+        self.register_provider(provider,
+                               namespaces=interop_namespace,
+                               schema_pragma_files=schema_pragma_file,
+                               verbose=verbose)
+
+        provider = CIMIndicationSubscriptionProvider(self.cimrepository)
+        self.register_provider(provider,
+                               namespaces=interop_namespace,
+                               schema_pragma_files=schema_pragma_file,
+                               verbose=verbose)
+
     ###########################################################################
     #
     #  Methods to compile mof files into repository
@@ -555,7 +665,7 @@ class FakedWBEMConnection(WBEMConnection):
         # By default, error messages are always printed in addition to being
         # raised as MOFCompileError. We only want them to be printed in verbose
         # mode:
-        log_func_kwargs = dict()
+        log_func_kwargs = {}
         if not verbose:
             log_func_kwargs['log_func'] = None
 
@@ -631,7 +741,7 @@ class FakedWBEMConnection(WBEMConnection):
         # By default, error messages are always printed in addition to being
         # raised as MOFCompileError. We only want them to be printed in verbose
         # mode:
-        log_func_kwargs = dict()
+        log_func_kwargs = {}
         if not verbose:
             log_func_kwargs['log_func'] = None
 
@@ -1170,8 +1280,7 @@ class FakedWBEMConnection(WBEMConnection):
                                 "pywbem.CIMParameter",
                                 methodname, localobject, type(param)))
         if params:
-            for pname in params:
-                pvalue = params[pname]
+            for pname, pvalue in params.items():
                 params_dict[pname] = CIMParameter(
                     pname, cimtype(pvalue), value=pvalue)
 
